# hriddhiraj_pattern

## This is a pattern printing program

---

# Use the package in your project

### Install the package

```
pip install hriddhiraj-pattern
```

### Using the package

```
import hriddhiraj-pattern.pattern as pattern

pattern.pattern_triangle(4)
```

---

Hriddhiraj sarkar © 2023

> **Note**
> This is for a university project. Might not be maintained in future.
